var __assign = this && this.__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

import { subtractDays, subtractMonths, subtractYears, getStartOfDayDate, getStartOfMonthDate, getStartOfYearDate } from "../../dateUtils";
import { useTimeseries } from "../../hooks";
import { formatNumber } from "../../utils";
import { automationRate, knowledgePool } from "./data-templates";
export var ChartType;

(function (ChartType) {
  ChartType["weekly"] = "weekly";
  ChartType["monthly"] = "monthly";
  ChartType["annual"] = "annual";
})(ChartType || (ChartType = {}));

var formatDate = function (timestamp) {
  var date = new Date(timestamp);
  var day = date.getDate();
  var month = date.getMonth() + 1;
  var year = date.getFullYear();
  return day + "." + month + "." + year;
};

export var configureDifferenceText = function (difference, differenceText, title, date) {
  var formattedDate = date ? formatDate(date) : 'yesterday';
  var text = differenceText.replace('{VALUE}', difference > 0 ? "+" + difference : String(difference)).replace('{DATE}', formattedDate);
  return title === knowledgePool.title ? text.replace('{S}', difference === 1 ? '' : 's') : text;
};
export var calculateAngle = function (title, todayValue, difference) {
  var angle = 0;

  if (title === automationRate.title) {
    angle = todayValue / 100 * 360;
  } else if (todayValue > 0) {
    angle = difference / todayValue * 360;
  }

  return Math.min(angle, 360);
};
export function getStatsData(config, data, viewType) {
  var _a = parseResult(data),
      yesterdayValue = _a[0],
      todayValue = _a[1];

  var difference = todayValue - yesterdayValue;
  var differenceDate = data.result && data.result.length && data.result[0].timestamp;
  var differenceText = configureDifferenceText(difference, config.differenceText, config.title, differenceDate);
  var angle = calculateAngle(config.title, todayValue, difference);
  return __assign(__assign({}, config), {
    differenceText: differenceText,
    valueText: config.valueText.replace('{VALUE}', formatNumber(todayValue)),
    angle: angle,
    error: data.error,
    viewType: viewType
  });
}
export function parseResult(result) {
  return [parseInt(result.result && result.result[0] ? result.result[0].value : '0'), parseInt(result.result && result.result[1] ? result.result[1].value : '0')];
}
export function useStatisticsData(client, name, _a) {
  var from = _a.from,
      to = _a.to,
      _b = _a.limit,
      limit = _b === void 0 ? 2 : _b;
  return useTimeseries(client, name, {
    from: from,
    to: to,
    limit: limit
  });
}
export function parseResultForChart(result, parseFn) {
  var resultArr = result.result;

  if (resultArr && resultArr.length >= 2) {
    return resultArr.map(function (resultItem) {
      return parseFn(resultItem);
    });
  } else return [{
    name: "",
    value: 0
  }];
}

function getMonthShortName(date) {
  return date.toLocaleString('en-GB', {
    month: 'short'
  });
}

export function mapDaysRateForCharts(item) {
  var date = new Date(item.timestamp);
  var day = date.getUTCDate();
  var month = getMonthShortName(date);
  return {
    name: day + " " + month,
    value: parseInt(item.value)
  };
}
export function mapMonthsRateForCharts(item) {
  var date = new Date(item.timestamp);
  var month = getMonthShortName(date);
  return {
    name: "" + month,
    value: parseInt(item.value)
  };
}
export function mapYearsRateForCharts(item) {
  var date = new Date(item.timestamp);
  var fullYear = date.getUTCFullYear();
  return {
    name: "" + fullYear,
    value: parseInt(item.value)
  };
}
export function createDaysArr(daysNumber, currentDate) {
  if (daysNumber === void 0) {
    daysNumber = 1;
  }

  var startOfDayDate = getStartOfDayDate(currentDate),
      resultArray = [startOfDayDate];

  for (var i = 1; i < daysNumber; i++) {
    var day = subtractDays(startOfDayDate, i);
    resultArray.push(day);
  }

  return resultArray.reverse();
}
export function createMonthsArr(monthsNumber, currentDate) {
  if (monthsNumber === void 0) {
    monthsNumber = 1;
  }

  var startOfMonthDate = getStartOfMonthDate(currentDate),
      resultArray = [startOfMonthDate];

  for (var i = 1; i < monthsNumber; i++) {
    var month = subtractMonths(startOfMonthDate, i);
    resultArray.push(month);
  }

  return resultArray.reverse();
}
export function createYearsArr(yearsNumber, currentDate) {
  if (yearsNumber === void 0) {
    yearsNumber = 1;
  }

  var startOfYearDate = getStartOfYearDate(currentDate),
      resultArray = [startOfYearDate];

  for (var i = 1; i < yearsNumber; i++) {
    var year = subtractYears(startOfYearDate, i);
    resultArray.push(year);
  }

  return resultArray.reverse();
}
export function getWeeksRate(controlData, controlDateList) {
  var daysRateResultList = controlDateList.map(function (controlDate) {
    var resultArr = controlData && controlData.result && controlData.result.filter(function (controlDataItem) {
      return controlDataItem.timestamp === controlDate;
    });
    return resultArr && resultArr[0] || {
      timestamp: controlDate,
      value: '0'
    };
  });
  return __assign(__assign({}, controlData), {
    result: daysRateResultList
  });
}
export function getMonthsRate(controlData, controlDateList) {
  var monthsRateResultList = controlDateList.map(function (controlDate) {
    var resultArr = controlData && controlData.result && controlData.result.filter(function (controlDataItem) {
      return controlDataItem.timestamp === controlDate;
    });
    return resultArr && resultArr[0] || {
      timestamp: controlDate,
      value: '0'
    };
  });
  return __assign(__assign({}, controlData), {
    result: monthsRateResultList
  });
}
export function getYearsRate(controlData, controlDateList) {
  var yearsRateResultList = controlDateList.map(function (controlDate) {
    var resultArr = controlData.result && controlData.result.filter(function (controlDataItem) {
      var controlDataItemDateFormat = new Date(controlDataItem.timestamp);
      var controlDateDateFormat = new Date(controlDate);
      return controlDataItemDateFormat.getUTCFullYear() === controlDateDateFormat.getUTCFullYear();
    });
    var result = resultArr && resultArr.length ? getMedian(resultArr).toString() : '0';
    return {
      timestamp: controlDate,
      value: result
    };
  });
  return __assign(__assign({}, controlData), {
    result: yearsRateResultList
  });
}

function getMedian(dataList) {
  if (dataList.length === 0) {
    return 0;
  }

  var sum = dataList.reduce(function (sum, currentValue) {
    return sum + Number(currentValue.value);
  }, 0);
  return Math.round(sum / dataList.length);
}