var __assign = this && this.__assign || function () {
  __assign = Object.assign || function (t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

var __rest = this && this.__rest || function (s, e) {
  var t = {};

  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

import { useContext } from 'react';
import { ThemeContext, ThemeProvider as Provider } from 'styled-components';
import merge from 'deepmerge';
import color from 'color';
export var defaultTheme = {
  colors: {
    primary: '#C7C7CB',
    secondary: '#E3E3E5',
    primaryText: '#76767C',
    secondaryText: '#B9B9BC',
    red: '#E82C2C',
    orange: '#E8A72C',
    yellow: '#EFEF2C',
    green: '#24D174',
    teal: '#09D0B1',
    blue: '#2CB2E8',
    purple: '#A913E0',
    pink: '#FC42AD',
    brown: '#814306',
    black: '#151515',
    grey: '#A0A0A0',
    white: '#fff'
  },
  greyscale: {
    lighter: '#F5F5F5',
    light: '#ECECEC',
    medium: '#D4D4D4',
    dark: '#C7C7CB',
    darker: '#76767C',
    darkest: '#393941'
  },
  global: {
    fontSize: '14px',
    fontFamily: "'Titillium Web','Helvetica Neue',Arial,Helvetica,sans-serif;"
  },
  font: {
    h1: {
      fontSize: 18,
      fontWeight: 400
    },
    h2: {
      fontSize: 16,
      fontWeight: 400
    },
    h3: {
      fontSize: 14,
      fontWeight: 400
    }
  },
  sizes: {
    borderRadius: '1.5em',
    padding: {
      normal: '0.5em',
      extra: '1rem 2.5rem'
    },
    scale: {
      mini: 11,
      tiny: 12,
      small: 13,
      medium: 14,
      large: 16,
      big: 18,
      huge: 20,
      massive: 24
    }
  },
  breakpoints: {
    sm: 576,
    md: 768,
    lg: 992,
    xl: 1200
  }
};
export var createColors = function (colors) {
  var res = {};

  for (var key in colors) {
    if (colors.hasOwnProperty(key)) {
      var cHex = colors[key];
      var c = color(cHex);

      if (key.endsWith('Text')) {
        res[key] = {
          default: cHex,
          active: (c.isDark() ? c.darken(0.2) : c.lighten(0.4)).hex(),
          hover: (c.isDark() ? c.lighten(0.4) : c.darken(0.2)).hex(),
          light: c.lighten(0.5).hex(),
          dark: c.darken(0.2).hex(),
          verylight: c.lighten(0.75).hex(),
          saturated: c.saturate(1.52).lighten(0.83).hex()
        };
        continue;
      }

      res[key] = {
        default: cHex,
        active: (c.isLight() ? c.darken(0.1) : c.lighten(0.2)).hex(),
        hover: (c.isLight() ? c.lighten(0.2) : c.darken(0.1)).hex(),
        light: c.lighten(0.65).hex(),
        dark: c.darken(0.3).hex(),
        verylight: c.lighten(0.95).hex(),
        saturated: c.saturate(1.52).lighten(0.83).hex()
      };
    }
  }

  return res;
};
export var createTheme = function (theme) {
  var _a = theme ? merge(defaultTheme, theme) : defaultTheme,
      colors = _a.colors,
      rest = __rest(_a, ["colors"]);

  return __assign({
    colors: createColors(colors)
  }, rest);
};
export var defaultCreatedTheme = createTheme();
export default defaultCreatedTheme;
export var useTheme = function () {
  return useContext(ThemeContext) || defaultCreatedTheme;
};
export var ThemeProvider = Provider;