import React from 'react';
import styled from 'styled-components';
import defaultTheme from '../../../theme';
import { MenuItem } from './MenuItem';
export const Menu = styled(({ children, theme, ...rest }) => {
    return (React.createElement("div", Object.assign({}, rest), React.Children.map(children, (child) => {
        const props = {
            color: rest.color,
            tabbed: rest.tabbed,
        };
        if (!child) {
            return null;
        }
        return React.cloneElement(child, props);
    })));
})({
    display: 'flex',
    alignItems: 'stretch',
    minHeight: '2.5em',
}, 
// Background color
({ color, theme, tabbed }) => tabbed
    ? { color: theme.colors[color || 'primary'].default }
    : {
        backgroundColor: color
            ? theme.colors[color].default
            : theme.colors.white.default,
    }, 
//Border
({ bordered, theme }) => bordered
    ? {
        borderBottom: `1px solid ${theme.greyscale.dark}`,
    }
    : null, 
// MenuItem border color
({ color, theme }) => {
    if (!color) {
        return;
    }
    return {
        [MenuItem]: {
            borderColor: theme.colors.white.default,
        },
    };
});
Menu.defaultProps = {
    theme: defaultTheme,
};
