import styled from 'styled-components';
import { clickable, primary } from '../../../utils';
import defaultTheme from '../../../theme';
export const MenuItem = styled.div({
    position: 'relative',
    display: 'flex',
    alignItems: 'center',
    padding: '1em 1.5em',
    '& h1, h2, h3': {
        padding: 0,
    },
}, 
// Colourable
(props) => (props.color && !props.tabbed ? primary(props) : null), 
// Make clickable
(props) => {
    if (!props.onClick && !props.href) {
        return;
    }
    if (!props.tabbed) {
        return clickable(props);
    }
    return {
        position: 'relative',
        cursor: 'pointer',
        transition: ' background-color .25s ease-out',
        '&:not(:last-child)': {
            marginRight: '1px',
        },
        '&:after': {
            content: '""',
            display: 'block',
            position: 'absolute',
            bottom: 0,
            left: 0,
            right: 0,
            height: 3,
            backgroundColor: props.theme.colors[props.color || 'primary'].default,
            opacity: 0,
            transition: 'opacity .25s ease-out',
            zIndex: 1,
        },
        '&:active:hover': {},
        '&:hover, &:focus': {
            backgroundColor: 'rgba(0, 0, 0, 0.01)',
            '&:after': {
                opacity: 1,
            },
        },
    };
}, 
//Active
({ active, tabbed }) => {
    if (!active) {
        return;
    }
    if (tabbed) {
        return {
            backgroundColor: 'rgba(0, 0, 0, 0.01)',
            '&:after': {
                opacity: 1,
            },
        };
    }
    // @todo
    return {};
}, 
// Border
({ border, theme }) => {
    if (!border) {
        return null;
    }
    return {
        [border === 'right'
            ? 'borderRight'
            : 'borderLeft']: `1px solid ${theme.greyscale.dark}`,
    };
}, 
// Position
({ position }) => {
    if (!position || position === 'left') {
        return null;
    }
    return {
        marginLeft: 'auto',
    };
});
MenuItem.defaultProps = {
    theme: defaultTheme,
};
