import { useEffect, useState } from 'react';
export const fetchTimeseriesVertexId = async (client, type) => {
    const query = `+(ogit\\/_type:"ogit/Timeseries" \\/DataName : "Dashboard.${type}")`;
    try {
        const timeseriesVertex = await client.lucene(query);
        return timeseriesVertex[0]['ogit/_id'];
    }
    catch (error) {
        console.error(error);
        throw new Error(error);
    }
};
export async function fetchTimeseriesValues(client, id, options) {
    try {
        return await client.streamts(id, options);
    }
    catch (error) {
        throw new Error(error);
    }
}
export function useTimeseries(client, type, options, initialResultValue) {
    const [result, setResult] = useState(initialResultValue);
    const [loading, setLoading] = useState(false);
    const [error, setError] = useState(false);
    const [fetchParams, setFetchParams] = useState(options);
    useEffect(() => {
        const fetchData = async () => {
            setError(false);
            setLoading(true);
            try {
                const timeseriesVertexId = await fetchTimeseriesVertexId(client, type);
                const timeseries = await fetchTimeseriesValues(client, timeseriesVertexId, fetchParams);
                setResult(timeseries);
            }
            catch (error) {
                setError(true);
            }
            setLoading(false);
        };
        fetchData();
    }, [client, type, fetchParams]);
    return [{ result, loading, error }, setFetchParams];
}
