import React, { useMemo, useState } from 'react';
import styled from 'styled-components';
import { ProgressBubbles, Box, } from '../../elements';
import { Button } from '../../inputs';
import { Loader } from '../../modules';
import { useWidgetContext } from '../context';
const convertToBoolean = (value) => value === 'true';
const getHandoverStatusIcon = (isHandover, conversionOwner) => {
    if (isHandover) {
        if (conversionOwner) {
            return 'conversionStarted';
        }
        return 'positive';
    }
    return 'none';
};
const calculateProgressBubbles = (value) => {
    const { 'ogit/_owner': owner, '/teaching_rooms': teachingRooms = 0, '/teaching_rooms_completed': teachingRoomsCompleted = 0, '/teaching_step_progress': teachingSteps = 0, '/teaching_steps_deployed': teachingStepsDeployed = 0, '/teaching_is_handedover': teachingIsHandedover = 'false', '/teaching_conversion_ownerId': conversionOwner, } = value;
    if (!owner) {
        return [];
    }
    return [
        {
            key: 'steps',
            content: {
                value: Number(teachingRoomsCompleted),
                total: Number(teachingRooms),
            },
            label: 'Steps',
        },
        {
            key: 'handover',
            content: getHandoverStatusIcon(convertToBoolean(teachingIsHandedover), conversionOwner),
            label: 'Handover',
        },
        {
            key: 'ki',
            content: {
                value: Number(teachingStepsDeployed),
                total: Number(teachingSteps),
            },
            label: 'KI',
        },
    ];
};
const SessionItem = ({ id, progress, title, action, appId, }) => {
    const [hover, setHover] = useState(false);
    return (React.createElement(Box, { direction: "row", verticalAlign: "center", onMouseEnter: () => setHover(true), onMouseLeave: () => setHover(false) },
        React.createElement(Box, { size: 0.25 },
            React.createElement("span", null, title)),
        React.createElement(Box, { size: 0.65, floated: "right", centered: hover }, hover ? (React.createElement(Button, { color: "blue", onClick: () => action(appId, { action: 'open-session', id }) }, "Continue Teaching")) : (React.createElement(ProgressBubbles, { progress: progress })))));
};
const ListContainer = styled.div({
    padding: '0.25em 0',
    [`& > ${Box}`]: {
        height: '4em',
        flexWrap: 'nowrap',
    },
});
export const SessionList = () => {
    const placeholder = 'Empty';
    const { provider: { openApp, selectAppsIds }, } = useWidgetContext();
    const data = {
        loading: false,
        error: false,
        result: [],
    };
    const appId = selectAppsIds().atqId;
    const progress = useMemo(() => {
        return ((data.result &&
            data.result.reduce((acc, d) => {
                acc[d['ogit/_id']] = {
                    progress: calculateProgressBubbles(d),
                    title: d['ogit/title'],
                    id: d['ogit/_id'],
                };
                return acc;
            }, {})) ||
            {});
    }, [data]);
    if (!data || data.loading) {
        return React.createElement(Loader, { active: true });
    }
    if (!data.result || data.result.length === 0) {
        return (React.createElement(Box, { centered: true, verticalAlign: "center" },
            React.createElement("span", null, placeholder)));
    }
    return (React.createElement(ListContainer, null, Object.entries(progress).map(([sessionId, progressData]) => (React.createElement(SessionItem, Object.assign({ key: sessionId, appId: appId, action: openApp }, progressData))))));
};
export default SessionList;
