import React, { useEffect, useState } from 'react';
import { Box } from '../../../elements';
import { useWidgetContext } from '../../context';
import { StatisticBox, StatisticsContainer, GoToLink, WidgetTitle, Header, LoaderWrapper, } from './styles';
import { StatisticColumn } from './StatisticColumn';
import { automatedTasks, automationRate, initialStatisticData, knowledgePool, statisticWidgetData, } from './mockData';
export const Statistic = () => {
    const { client, config: { title }, } = useWidgetContext();
    const placeholder = 'Empty';
    const [data, setData] = useState(statisticWidgetData);
    useEffect(() => {
        const fetchData = async () => {
            try {
                setData({ result: initialStatisticData, loading: true, error: false });
                /* mock asyncs */
                const automationRateData = await Promise.resolve(automationRate);
                const automatedTaskData = await Promise.resolve(automatedTasks);
                const knowledgePoolData = await Promise.resolve(knowledgePool);
                setData({
                    loading: false,
                    error: false,
                    result: [automationRateData, automatedTaskData, knowledgePoolData],
                });
            }
            catch (e) {
                setData({ result: [], error: true, loading: false });
            }
        };
        fetchData();
    }, []);
    if (!data.loading && (!data.result || data.result.length === 0)) {
        return (React.createElement(Box, { centered: true, verticalAlign: "center" },
            React.createElement("span", null, placeholder)));
    }
    if (data.error) {
        return (React.createElement(Box, { centered: true, verticalAlign: "center" },
            React.createElement("span", null, "Fetching Error")));
    }
    return (React.createElement(StatisticBox, null,
        React.createElement(Header, null,
            React.createElement(WidgetTitle, null, title),
            React.createElement(GoToLink, null, "Go to HIRO Portal")),
        React.createElement(StatisticsContainer, null,
            data.result.map(({ title, differenceText, whatItIs, howToImprove, angle, valueText, valueColor, backgroundColor, }) => (React.createElement(StatisticColumn, { title: title, whatItIs: whatItIs, howToImprove: howToImprove, differenceText: differenceText, angle: angle, valueText: valueText, valueColor: valueColor, backgroundColor: backgroundColor, key: title }))),
            data.loading && React.createElement(LoaderWrapper, null))));
};
export default Statistic;
