import React from 'react';
import styled from 'styled-components';
import { InfoCircle } from '../../../icons';
import { Button } from '../../../inputs/Button';
import { Box } from '../../../elements/Flex';
import defaultTheme from '../../../../theme';
import { Loader } from '../../../modules/Loader';
export const Header = styled.div `
  width: 100%;
  display: flex;
  justify-content: space-between;
  flex-wrap: wrap;
  align-items: center;
`;
export const WidgetTitle = styled.span `
  font-size: 18px;
  font-weight: bold;
  line-height: 35px;
  color: #393941;
`;
export const TitleText = styled.span `
  color: #519375;
  font-size: 16px;
  width: 100%;
  text-align: center;
  padding-top: 20px;
  padding-bottom: 20px;
`;
export const StatisticsContainer = styled.div `
  display: flex;
  flex-direction: row;
  justify-content: space-around;
  flex-wrap: wrap;
  width: 100%;
  padding-bottom: 40px;
`;
export const StatisticsColumn = styled.div `
  display: flex;
  flex-direction: column;
  width: 33.3%;
  min-width: 180px;
`;
export const DiffText = styled.div `
  color: #afafaf;
  font-size: 14px;
  width: 100%;
  text-align: center;
  padding-top: 20px;
`;
export const InfoIcon = styled(InfoCircle)({
    fill: '#519375',
    paddingBottom: '6px',
    paddingLeft: '4px',
    width: '14px',
});
export const InfoBody = styled.div({
    fontSize: 10,
    maxWidth: 220,
    textAlign: 'left',
});
export const GoToLink = styled(Button).attrs({
    as: 'a',
    href: 'https://hiro.arago.co/',
    target: '_blank noopener noreferer',
    secondary: true,
    color: 'green',
})({
    textDecoration: 'none',
    '&:hover, &:focus': {
        color: '#1DA75D',
    },
});
export const StatisticBox = styled(Box).attrs({
    centered: true,
    verticalAlign: 'center',
})(({ theme }) => ({
    borderRadius: theme.sizes.borderRadius,
    flexWrap: 'nowrap',
}));
const LoaderWrapperComponent = styled.div({
    width: '100%',
    height: '100%',
    background: '#fff',
    position: 'absolute',
    top: 0,
    left: 0,
});
export const LoaderWrapper = () => (React.createElement(LoaderWrapperComponent, null,
    React.createElement(Loader, { active: true })));
StatisticBox.defaultProps = {
    theme: defaultTheme,
};
