import { useMemo, lazy } from 'react';
/**
 * Async component loading for use with Dashboard.
 *
 * Should be used with component wrapped in `React.Suspense`
 *
 * @example
 * ```
 * const AsyncHeader = () => {
 *  const Header = useAsyncComponent('Header');
 *
 *  return <Header>Hello world!</Header>
 * }
 *
 * ...
 *
 * <React.Suspense fallback={<Loader active />}>
 *   <AsyncHeader />
 * </React.Suspense>
 * ```
 */
export const useWidget = (type) => {
    return useMemo(() => {
        switch (type) {
            case 'SessionList':
                return lazy(() => import('./SessionList'));
            case 'Statistic':
                return lazy(() => import('./Statistic/Statistic'));
            case 'Welcome':
                return lazy(() => import('./welcome/Welcome'));
            case 'TopContributors':
                return lazy(() => import('./TopContributors/TopContributors'));
            case 'Demo':
                return lazy(() => import('./Demo'));
            default:
                if (type) {
                    console.warn(`Async component '${type}' not supported`);
                }
                return lazy(() => import('../../elements/Flex/Box'));
        }
    }, [type]);
};
