import React from 'react';
import { useLucene } from '../../hooks';
import { Box } from '../../../elements';
import { Loader } from '../../../modules';
import { useWidgetContext } from '../../context';
import { SessionsButton } from './SessionsButton';
import { SessionsButtonText } from './SessionsButtonText';
import { Header, WidgetTitle } from './styles';
const configureQuery = (type, accountId) => {
    const baseQuery = '+(ogit\\/_type:"ogit/Knowledge/AcquisitionSession")';
    const filterQueries = {
        new: `+(-\\/teaching_ownerId:* -\\/teaching_is_handedover:"true" -ogit\\/Knowledge\\/archived:"true")`,
        started: `+(+\\/teaching_ownerId:"${accountId}" -\\/teaching_without_issue:"true" -ogit\\/Knowledge\\/archived:"true")`,
    };
    return {
        querystring: `${baseQuery} ${filterQueries[type]}`,
        params: { limit: -1, count: true },
    };
};
export const Welcome = () => {
    const { client, provider: { selectMe, selectAppsIds, openApp }, config: { title }, } = useWidgetContext();
    const me = selectMe();
    const newSessionsCountQuery = configureQuery('new');
    const startedSessionsCountQuery = configureQuery('started', me.accountId);
    const [newSessionsCount] = useLucene(client, newSessionsCountQuery, 0);
    const [startedSessionsCount] = useLucene(client, startedSessionsCountQuery, 0);
    const loading = newSessionsCount.loading || startedSessionsCount.loading;
    const error = newSessionsCount.error || startedSessionsCount.error;
    const { atqId } = selectAppsIds();
    const greeting = `${title} ${me.displayName || ''}!`;
    const content = error || (React.createElement(React.Fragment, null,
        React.createElement(Box, { floated: "left" },
            React.createElement(Header, null,
                React.createElement(WidgetTitle, null, greeting)),
            React.createElement(Header, { as: "h3" },
                React.createElement("span", null, "Nice to have you here! Let\u2019s get some work done together!"))),
        React.createElement("br", null),
        React.createElement(Box, { direction: "row", centered: "spaced" },
            React.createElement(SessionsButton, { text: "Start Teaching", color: "#519375", onClick: () => openApp(atqId, { action: 'show-new-sessions' }) },
                React.createElement(Box, null,
                    React.createElement(SessionsButtonText, { fontSize: "18px" }, "New Tasks"),
                    React.createElement(SessionsButtonText, { fontSize: "88px" }, newSessionsCount.result))),
            React.createElement(SessionsButton, { text: "Continue Teaching", color: "#79B79B", onClick: () => openApp(atqId, { action: 'show-started-sessions' }) },
                React.createElement(Box, null,
                    React.createElement(SessionsButtonText, { fontSize: "18px" }, "Started Tasks"),
                    React.createElement(SessionsButtonText, { fontSize: "88px" }, startedSessionsCount.result))))));
    return (React.createElement(Box, { centered: true },
        content,
        React.createElement(Loader, { active: loading })));
};
export default Welcome;
