import React from 'react';
import styled from 'styled-components';
import { Handover } from '../../icons';
import defaultTheme, { useTheme } from '../../../theme';
/**
 * Progress calculators
 */
const calculateProgressContent = (content) => {
    const borderHexColor = 'blue';
    if (typeof content === 'string') {
        return getIconContent(content);
    }
    const lineHexColor = content.value > 0 && content.value === content.total ? 'blue' : 'secondary';
    return {
        labelContent: getProgressContent(content),
        lineHexColor,
        borderHexColor,
    };
};
const calculateProgressCoordinates = (content) => {
    if (!hasProgress(content)) {
        return {};
    }
    const R = 100;
    let alpha = (360 / content.total) * content.value;
    const a = ((90 - alpha) * Math.PI) / 180;
    const x = alpha === 360 ? -0.1 : Math.round(R * Math.cos(a));
    const y = Math.round(-R * Math.sin(a));
    return { x, y, center: alpha > 180 || x < 0 ? 1 : 0 };
};
const calculateProgressLine = (content) => {
    if (content === 'positive') {
        return { x: -0.1, y: -100, center: 1 };
    }
    return calculateProgressCoordinates(content);
};
const hasProgress = (content) => typeof content !== 'string' &&
    content.value !== 0 &&
    content.total >= content.value;
/**
 * Styled Content
 */
const ProgressBubbleContentContainer = styled.div({
    display: 'flex',
    height: '100%',
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: 'space-between',
    padding: '10px 0',
});
const ProgressBubbleText = styled.span({
    fontSize: '10px',
    lineHeight: '5px',
});
const ProgressBubbleBorder = styled.span({
    display: 'block',
    width: '20px',
    borderTop: '1px solid #f5f5f5',
});
const getProgressContent = (content) => (React.createElement(ProgressBubbleContentContainer, null,
    React.createElement(ProgressBubbleText, null, content.value),
    React.createElement(ProgressBubbleBorder, null),
    React.createElement(ProgressBubbleText, null, content.total)));
const getIconColors = (status) => {
    switch (status) {
        case 'positive':
            return { lineColor: 'primary', iconColor: 'blue' };
        case 'conversionStarted':
            return { lineColor: 'blue', iconColor: 'blue' };
        default:
            return { lineColor: 'secondary', iconColor: 'primary' };
    }
};
const getIconContent = (status) => {
    const { iconColor, lineColor } = getIconColors(status);
    const labelContent = React.createElement(Handover, { color: iconColor });
    return {
        labelContent,
        lineHexColor: lineColor,
        borderHexColor: iconColor,
    };
};
const ProgressLine = styled.div({
    width: '100%',
    height: '4px',
}, ({ theme, color }) => color
    ? {
        background: theme.colors[color].default,
    }
    : null);
ProgressLine.defaultProps = {
    theme: defaultTheme,
};
const ProgressBubbleLabel = styled.div({
    position: 'relative',
    width: '45px',
    height: '45px',
    margin: '0 !important',
    lineHeight: '20px',
    borderRadius: '50%',
}, ({ theme }) => ({ backgroundColor: theme.greyscale.light }));
ProgressBubbleLabel.defaultProps = {
    theme: defaultTheme,
};
const ProgressIndicator = styled.svg({
    position: 'absolute',
    top: '2px',
    left: 0,
});
const ProgressBubble = styled.div({
    position: 'relative',
    display: 'flex',
    width: '45px',
    flexFlow: 'column nowrap',
    flexShrink: 0,
    alignItems: 'center',
    justifyContent: 'center',
    padding: '2px',
    textAlign: 'center',
});
/**
 * Progress Bubble
 */
export const ProgressBubbleContent = ({ content, showLine, label, }) => {
    const { labelContent, lineHexColor, borderHexColor, } = calculateProgressContent(content);
    const showProgressIndicator = hasProgress(content) && label !== 'Handover';
    const { x, y, center } = calculateProgressLine(content);
    const { colors } = useTheme();
    return (React.createElement(React.Fragment, null,
        React.createElement(ProgressBubble, null,
            React.createElement(ProgressBubbleLabel, null, labelContent),
            showProgressIndicator && (React.createElement(ProgressIndicator, { viewBox: "-106 -106 212 212" },
                React.createElement("path", { d: `M 0,-100 A 100,100 0 ${center || 0},1 ${x || 0},${y || 0}`, fill: "none", strokeWidth: "12", stroke: colors[borderHexColor].default })))),
        showLine && React.createElement(ProgressLine, { color: lineHexColor })));
};
