import React, { useCallback, useState } from 'react';
import styled from 'styled-components';
import { Check } from '../../icons';
import defaultTheme from '../../../theme';
/**
 * Hidden checkbox
 */
const HiddenCheckbox = styled.input.attrs({ type: 'checkbox' }) `
  // Hide checkbox visually but remain accessible to screen readers.
  // Source: https://polished.js.org/docs/#hidevisually
  border: 0;
  clip: rect(0 0 0 0);
  clippath: inset(50%);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  white-space: nowrap;
  width: 1px;
`;
const CustomCheckbox = styled.div({
    width: '20px',
    height: '20px',
    display: 'inline-block',
    position: 'relative',
    borderRadius: '5px',
}, 
// Themed
({ theme }) => ({
    border: `1px solid ${theme.greyscale.medium}`,
}), 
// Add margin for label
({ hasLabel }) => hasLabel
    ? {
        marginRight: '0.5em',
    }
    : null);
CustomCheckbox.defaultProps = {
    theme: defaultTheme,
};
/**
 * Checkbox styled components
 */
const StyledLabel = styled.label({
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'start',
    cursor: 'pointer',
}, 
// States
({ theme }) => ({
    '&:focus, &:focus:hover, &:hover': {
        [CustomCheckbox]: {
            borderColor: theme.colors.primary.default,
        },
    },
    '&:hover': {
        [CustomCheckbox]: {
            boxShadow: `1px 1px 12px 0 ${theme.greyscale.dark}`,
        },
    },
}));
StyledLabel.defaultProps = {
    theme: defaultTheme,
};
const StyledDiv = styled.div({
    display: 'inline-block',
    alignSelf: 'flex-start',
});
/**
 * Check icon
 */
const StyledCheck = styled(Check)(({ theme }) => ({
    fill: theme.colors.primaryText.default,
    transition: 'all .2s',
    position: 'absolute',
    top: '2px',
    left: '2px',
}));
StyledCheck.defaultProps = {
    theme: defaultTheme,
};
/**
 * Checkbox input
 */
export const Checkbox = ({ children, checked, onChange, ...rest }) => {
    const isControlled = checked !== undefined;
    const [currentValue, setCurrentValue] = useState(false);
    const usedValue = isControlled ? checked : currentValue;
    const handleChange = useCallback((e) => {
        if (!isControlled) {
            setCurrentValue(e.target.checked);
            return;
        }
        if (onChange) {
            onChange(e);
        }
    }, [onChange, isControlled]);
    return (React.createElement(StyledDiv, null,
        React.createElement(StyledLabel, null,
            React.createElement(CustomCheckbox, { hasLabel: !!children }, usedValue && React.createElement(StyledCheck, { width: 14, height: 14 })),
            React.createElement(HiddenCheckbox, Object.assign({}, rest, { checked: usedValue, onChange: handleChange })),
            children)));
};
