import React, { useCallback, useEffect, useState, useRef } from 'react';
import styled from 'styled-components';
import { Search as SearchIcon, Times as TimesIcon } from '../../icons';
import { StyledInput } from './StyledInput';
import defaultTheme from '../../../theme';
const Wrapper = styled.div(({ theme, active }) => ({
    position: 'relative',
    '& svg': {
        cursor: 'pointer',
        fill: theme.colors.primary[active ? 'dark' : 'light'],
        width: '1em',
        position: 'absolute',
        transform: 'translate(-1.5em, 5px) scale(0.7)',
    },
    '&:focus svg, &:focus:hover svg, &:hover svg': {
        fill: theme.colors.primary.dark,
    },
    [StyledInput]: {
        paddingRight: '2.2em',
        boxSizing: 'border-box',
    },
}), ({ open }) => open
    ? {
        [StyledInput]: {
            borderBottomLeftRadius: 0,
            borderBottomRightRadius: 0,
        },
    }
    : null);
Wrapper.defaultProps = {
    theme: defaultTheme,
};
const Results = styled.div `
  position: absolute;
  top: 2em;
  left: 0;
  right: 0;
  z-index: 100;

  background-color: white;
  border-bottom-left-radius: ${({ theme }) => theme.sizes.borderRadius};
  border-bottom-right-radius: ${({ theme }) => theme.sizes.borderRadius};
  border: 1px solid ${({ theme }) => theme.colors.primary.light};
  max-height: 16em;
  overflow-x: hidden;
  overflow-y: auto;

  box-sizing: border-box;
`;
Results.defaultProps = {
    theme: defaultTheme,
};
export const Search = ({ onClear, children, className, ...rest }) => {
    const ref = useRef(null);
    const Icon = rest.value ? TimesIcon : SearchIcon;
    const [isOpen, setOpen] = useState(false);
    // Re-open or close
    const handleClick = useCallback((e) => {
        // @ts-ignore
        if (ref && ref.current && ref.current.contains(e.target)) {
            setOpen(true);
            return;
        }
        setOpen(false);
    }, []);
    useEffect(() => {
        document.addEventListener('mousedown', handleClick, false);
        return () => document.removeEventListener('mousedown', handleClick, false);
    }, [handleClick]);
    const showResults = isOpen && !!children;
    return (React.createElement(Wrapper, { active: !!rest.value, open: showResults, ref: ref, className: className },
        React.createElement(StyledInput, Object.assign({}, rest)),
        React.createElement(Icon, { onClick: onClear }),
        showResults && React.createElement(Results, null, children)));
};
