import React from 'react';
import styled from 'styled-components';
import { Spinner } from '../../icons';
import defaultTheme from '../../../theme';
const SIZES = {
    mini: '14px',
    tiny: '16px',
    small: '24px',
    medium: '32px',
    large: '48px',
    big: '52px',
    huge: '58px',
    massive: '64px',
};
const baseStyle = ({ inline }) => {
    if (inline) {
        return {
            margin: inline === 'fitted' ? '0' : '0 0.25em',
            width: '1em',
            height: '1em',
        };
    }
    return {
        position: 'absolute',
        top: '50%',
        left: '50%',
        transform: 'translateX(-50%) translateY(-50%)',
        zIndex: 1000,
    };
};
const display = ({ inline, active, centered, children, }) => {
    if (!active) {
        return { display: 'none' };
    }
    if (centered) {
        return { display: 'flex', justifyContent: 'center' };
    }
    if (inline) {
        return { display: 'inline-block' };
    }
    if (children) {
        return { display: 'flex', flexFlow: 'column nowrap', alignItems: 'center' };
    }
    return { display: 'block' };
};
const LoaderDiv = styled.div({
    textAlign: 'center',
    margin: 0,
}, baseStyle, ({ centered }) => (centered ? { width: '100%' } : null), ({ theme, inverted, size }) => {
    const color = theme.colors[inverted ? 'white' : 'primaryText'].default;
    return {
        color,
        fontSize: SIZES[size || 'medium'],
        '& > svg': {
            display: 'block',
            width: '1em',
            height: '1em',
            fill: color,
        },
        '& > .content': {
            fontSize: '0.5em',
        },
    };
}, display);
LoaderDiv.defaultProps = {
    theme: defaultTheme,
};
export const Loader = ({ children, ...rest }) => (React.createElement(LoaderDiv, Object.assign({}, rest),
    React.createElement(Spinner, { loading: true }),
    children && React.createElement("div", { className: "content" }, children)));
