import { useContext } from 'react';
import { ThemeContext, ThemeProvider as Provider, } from 'styled-components';
import merge from 'deepmerge';
import color from 'color';
export const defaultTheme = {
    colors: {
        primary: '#C7C7CB',
        secondary: '#E3E3E5',
        primaryText: '#76767C',
        secondaryText: '#B9B9BC',
        red: '#E82C2C',
        orange: '#E8A72C',
        yellow: '#EFEF2C',
        green: '#24D174',
        teal: '#09D0B1',
        blue: '#2CB2E8',
        purple: '#A913E0',
        pink: '#FC42AD',
        brown: '#814306',
        black: '#151515',
        grey: '#A0A0A0',
        white: '#fff',
    },
    greyscale: {
        lighter: '#F5F5F5',
        light: '#ECECEC',
        medium: '#D4D4D4',
        dark: '#C7C7CB',
        darker: '#76767C',
        darkest: '#393941',
    },
    global: {
        fontSize: '14px',
        fontFamily: "'Titillium Web','Helvetica Neue',Arial,Helvetica,sans-serif;",
    },
    font: {
        h1: {
            fontSize: 18,
            fontWeight: 400,
        },
        h2: {
            fontSize: 16,
            fontWeight: 400,
        },
        h3: {
            fontSize: 14,
            fontWeight: 400,
        },
    },
    sizes: {
        borderRadius: '1.5em',
        padding: {
            normal: '0.5em',
            extra: '1rem 2.5rem',
        },
        scale: {
            mini: 11,
            tiny: 12,
            small: 13,
            medium: 14,
            large: 16,
            big: 18,
            huge: 20,
            massive: 24,
        },
    },
    breakpoints: {
        sm: 576,
        md: 768,
        lg: 992,
        xl: 1200,
    },
};
export const createColors = (colors) => {
    let res = {};
    for (const key in colors) {
        if (colors.hasOwnProperty(key)) {
            const cHex = colors[key];
            const c = color(cHex);
            if (key.endsWith('Text')) {
                res[key] = {
                    default: cHex,
                    active: (c.isDark() ? c.darken(0.2) : c.lighten(0.4)).hex(),
                    hover: (c.isDark() ? c.lighten(0.4) : c.darken(0.2)).hex(),
                    light: c.lighten(0.5).hex(),
                    dark: c.darken(0.2).hex(),
                    verylight: c.lighten(0.75).hex(),
                };
                continue;
            }
            res[key] = {
                default: cHex,
                active: (c.isLight() ? c.darken(0.1) : c.lighten(0.2)).hex(),
                hover: (c.isLight() ? c.lighten(0.2) : c.darken(0.1)).hex(),
                light: c.alpha(0.5).toString(),
                dark: c.darken(0.2).hex(),
                verylight: c.alpha(0.25).toString(),
            };
        }
    }
    return res;
};
export const createTheme = (theme) => {
    const { colors, ...rest } = theme
        ? merge(defaultTheme, theme)
        : defaultTheme;
    return {
        colors: createColors(colors),
        ...rest,
    };
};
export const defaultCreatedTheme = createTheme();
export default defaultCreatedTheme;
export const useTheme = () => useContext(ThemeContext) || defaultCreatedTheme;
export const ThemeProvider = Provider;
