const getBreakpoint = (theme, value) => typeof value === 'number' ? value : theme.breakpoints[value];
/**
 * Any screen width up to the selected breakpoint
 * @param bp Select breakpoint to go up to
 */
export const above = (bp) => ({ theme }) => `@media only screen and (min-width: ${getBreakpoint(theme, bp)}px)`;
/**
 * Any screen width down to the selected breakpoint
 * @param bp Select breakpoint to go down to
 */
export const below = (bp) => ({ theme }) => `@media only screen and (max-width: ${getBreakpoint(theme, bp) - 0.02}px)`;
/**
 * Any screen width between the selected breakpoints
 * @param a Select start breakpoint
 * @param b Select end breakpoint to go up to
 */
export const between = (min, max) => ({ theme, }) => `@media only screen and (min-width: ${getBreakpoint(theme, min)}px) and (max-width: ${getBreakpoint(theme, max) - 0.02}px)`;
/**
 * Any screen size between medium
 */
export const sm = below('md');
/**
 * Any screen size between medium and large
 */
export const md = between('md', 'lg');
/**
 * Any screen size between large and extra large
 */
export const lg = between('lg', 'xl');
/**
 * Any screen size above extra large
 */
export const xl = above('xl');
