import { xl, sm, md, lg } from './breakpoints';
export const flexbox = ({ size, theme, }) => {
    if (!size) {
        return;
    }
    const res = {};
    const sizeArray = (Array.isArray(size) ? size : [1, size]).map((i) => Math.min(Math.max(i, 0), 1));
    const lastSize = sizeArray[sizeArray.length - 1];
    for (let i = 0; i < 4; i++) {
        let query = '';
        switch (i) {
            case 0:
                query = sm({ theme });
                break;
            case 1:
                query = md({ theme });
                break;
            case 2:
                query = lg({ theme });
                break;
            default:
                query = xl({ theme });
                break;
        }
        res[query] = {
            flexBasis: `${100 * (sizeArray[i] || lastSize)}%`,
        };
    }
    return res;
};
const alignable = (isRow) => ({ verticalAlign, centered, floated, }) => {
    const s = {};
    if (!verticalAlign && !floated && !centered && !isRow) {
        return;
    }
    if (verticalAlign) {
        s[isRow ? 'alignItems' : 'justifyContent'] = verticalAlign;
    }
    if (floated) {
        s[floated === 'left' ? 'marginRight' : 'marginLeft'] = 'auto';
    }
    if (centered) {
        s[!isRow ? 'alignItems' : 'justifyContent'] =
            centered === true ? 'center' : 'space-around';
    }
    if (isRow) {
        s.width = '100%';
    }
    return s;
};
export const alignRow = alignable(true);
export const alignColumn = alignable();
