import { HiroPartialTheme } from '../../types';
export declare type Widgets = 'Welcome' | 'SessionList' | 'Demo' | 'TopContributors' | 'Statistic';
export interface Contributors {
    [key: string]: number;
}
/**
 * Basic Widget config
 */
export interface BaseWidgetConfig {
    size?: string | number;
    title?: string;
    as: Widgets;
}
/**
 * Advanced Widget config with automatic data loading
 */
export interface Me {
    id: string;
    accountId: string;
    email: string;
    displayName: string;
    roles: string[];
}
export interface WidgetProvider {
    openApp: (appId: string, options: any) => void;
    selectMe: () => Me;
    selectAppsIds: () => {
        [key: string]: string;
    };
    getEnvUrls: () => {
        [key: string]: string;
    };
}
export interface DashboardConfig {
    theme: HiroPartialTheme;
    widgets: Record<string, WidgetConfig>;
}
/**
 * Widgets
 */
export interface WelcomeWidgetConfig extends BaseWidgetConfig {
    as: 'Welcome';
}
export interface SessionListWidgetConfig extends BaseWidgetConfig {
    as: 'SessionList';
}
export interface DemoWidgetConfig extends BaseWidgetConfig {
    as: 'Demo';
}
export interface TopContributorsWidgetConfig extends BaseWidgetConfig {
    as: 'TopContributors';
}
export interface StatisticWidgetConfig extends BaseWidgetConfig {
    as: 'Statistic';
}
export declare type WidgetConfig = WelcomeWidgetConfig | SessionListWidgetConfig | DemoWidgetConfig | TopContributorsWidgetConfig | StatisticWidgetConfig;
export interface WidgetProps {
    as: Widgets;
}
